@@ -75,7 +75,7 @@ def decodeSetGovVariableHeight(hex):
         variables = [
             {'key':'attributes', 'type': [
                 {'bytesCount': 4, 'key': 'unknown', 'type': int,'endian':None},
-                {'bytesCount': 1, 'key': 'type', 'type': str,'endian':None},
+                {'bytesCount': 1, 'key': 'type', 'type': str,'endian':None,'abort':['o']},
                 {'bytesCount': 1, 'key': 'typeId', 'type': int,'endian':None},
                 {'bytesCount': 4, 'key': 'key', 'type': str,'endian':'big'},
                 {'bytesCount': 4, 'key': 'keyId', 'type': int,'endian':'little'},
@@ -149,7 +149,8 @@ def decodeCreatePoolPair(hex):
         {'bytesCount':1, 'key': 'tokenIdB', 'type': int,'endian':None},
         {'bytesCount': 8, 'key': 'commission', 'type': int,'endian':'little'},
         {'key': 'from', 'type': 'address','endian':None},
-        {'bytesCount':1, 'key': 'status', 'type': int,'endian':None}
+        {'bytesCount':1, 'key': 'status', 'type': int,'endian':None},
+        {'key': 'customRewards', 'type': 'rest' ,'endian':None}
     ]
     return searchHex(variables,hex)
 def decodeAccountToAccount(hex):
@@ -198,6 +199,7 @@ def decodePaybackLoanV2(hex):
     ]
     return searchHex(variables,hex)
 def recursiveSearchHex(variable,hex):
+    abort = False
     if type(variable['type']) == list:
         cnt = int(hex[:2],16)
         hex = hex[2:]
@@ -205,21 +207,27 @@ def recursiveSearchHex(variable,hex):
         for i in range(0,cnt):
             res = {}
             for idx,listVariable in enumerate(variable['type']):
-                (key,value,hex) = recursiveSearchHex(listVariable,hex)
+                (key,value,hex,abort) = recursiveSearchHex(listVariable,hex)
+                if 'abort' in variable['type'][idx] and value in variable['type'][idx]['abort']:
+                    abort = True
+                    break
                 if key is None and idx == len(variable['type']) - 1:
                     res = value
                 else:
                     res[key] = value
             arr.append(res)
-        return variable['key'],arr,hex
+        return variable['key'],arr,hex,abort
     else:
-        return getValue(variable,hex)
+        (key,value,hex) = getValue(variable,hex)
+        return key,value,hex,abort
 
 def searchHex(variables:list,hex:str):
     res = {}
     for variable in variables:
-        (key,value,hex) = recursiveSearchHex(variable,hex)
+        (key,value,hex,abort) = recursiveSearchHex(variable,hex)
         res[key] = value
+        if abort:
+            break
     
     if len(hex) == 0:
         res['hex'] = None
@@ -260,6 +268,9 @@ def getValue(variable,hex):
             addressLength = int(hex[4:6],16)
             hexOfInterest = hex[6:6+2*addressLength]
             hex = hex[2+2*hexLength:]
+    elif variable['type'] == 'rest':
+        hexOfInterest = hex
+        hex = ''
     else:
         hexOfInterest = hex[:2*variable['bytesCount']]
         hex = hex[2*variable['bytesCount']:]
